@@ -3,11 +3,12 @@
 #ifndef PBCOPPER_CLI_PARSER_H
 #define PBCOPPER_CLI_PARSER_H
 
+#include <pbcopper/PbcopperConfig.h>
+
 #include <memory>
 #include <string>
 #include <vector>
 
-#include <pbcopper/PbcopperConfig.h>
 #include <pbcopper/cli/Results.h>
 
 namespace PacBio {
@@ -15,10 +16,6 @@ namespace CLI {
 
 class Interface;
 
-namespace internal {
-class ParserPrivate;
-}
-
 ///
 /// \brief The Parser class
 ///
@@ -34,8 +31,9 @@ public:
     ///
     Parser(const Interface& interface);
 
-    Parser(const Parser& other);
-    ~Parser(void);
+    Parser(Parser&&) noexcept;
+    Parser& operator=(Parser&&) noexcept;
+    ~Parser();
 
     /// \}
 
@@ -61,7 +59,8 @@ public:
     /// \}
 
 private:
-    std::unique_ptr<internal::ParserPrivate> d_;
+    class ParserPrivate;
+    std::unique_ptr<ParserPrivate> d_;
 };
 
 }  // namespace CLI
