@@ -3,10 +3,10 @@
 #ifndef PBCOPPER_CLI_TOOLCONTRACT_INPUTFILETYPE_H
 #define PBCOPPER_CLI_TOOLCONTRACT_INPUTFILETYPE_H
 
-#include <string>
-
 #include <pbcopper/PbcopperConfig.h>
 
+#include <string>
+
 namespace PacBio {
 namespace CLI {
 namespace ToolContract {
@@ -16,14 +16,11 @@ class InputFileType
 public:
     InputFileType(std::string id, std::string title, std::string description, std::string type);
 
-    InputFileType(const InputFileType&) = default;
-    ~InputFileType(void) = default;
-
 public:
-    const std::string& Id(void) const;
-    const std::string& Title(void) const;
-    const std::string& Description(void) const;
-    const std::string& Type(void) const;
+    const std::string& Id() const;
+    const std::string& Title() const;
+    const std::string& Description() const;
+    const std::string& Type() const;
 
 private:
     std::string id_;
