@@ -3,10 +3,10 @@
 #ifndef PBCOPPER_CLI_TOOLCONTRACT_OUTPUTFILETYPE_H
 #define PBCOPPER_CLI_TOOLCONTRACT_OUTPUTFILETYPE_H
 
-#include <string>
-
 #include <pbcopper/PbcopperConfig.h>
 
+#include <string>
+
 namespace PacBio {
 namespace CLI {
 namespace ToolContract {
@@ -17,15 +17,12 @@ public:
     OutputFileType(std::string id, std::string title, std::string description, std::string type,
                    std::string defaultName);
 
-    OutputFileType(const OutputFileType&) = default;
-    ~OutputFileType(void) = default;
-
 public:
-    const std::string& Id(void) const;
-    const std::string& Title(void) const;
-    const std::string& DefaultName(void) const;
-    const std::string& Description(void) const;
-    const std::string& Type(void) const;
+    const std::string& Id() const;
+    const std::string& Title() const;
+    const std::string& DefaultName() const;
+    const std::string& Description() const;
+    const std::string& Type() const;
 
 private:
     std::string id_;
