@@ -3,30 +3,28 @@
 #ifndef PBCOPPER_CLI_TOOLCONTRACT_RESOLVEDTOOLCONTRACT_H
 #define PBCOPPER_CLI_TOOLCONTRACT_RESOLVEDTOOLCONTRACT_H
 
+#include <pbcopper/PbcopperConfig.h>
+
 #include <iosfwd>
 
-#include <pbcopper/PbcopperConfig.h>
 #include <pbcopper/cli/Results.h>
 
 namespace PacBio {
 namespace CLI {
 namespace ToolContract {
 
-namespace internal {
-class RtcPrivate;
-}
-
 class ResolvedToolContract
 {
 public:
     ResolvedToolContract(Interface interface);
-    ~ResolvedToolContract(void);
+    ~ResolvedToolContract();
 
 public:
     Results Parse(std::istream& in);
 
 private:
-    std::unique_ptr<internal::RtcPrivate> d_;
+    class ResolvedToolContractPrivate;
+    std::unique_ptr<ResolvedToolContractPrivate> d_;
 };
 
 }  // namespace ToolContract
