@@ -5,10 +5,23 @@
 
 #include <pbcopper/cli/toolcontract/Driver.h>
 
+#include <cassert>
+#include <type_traits>
+
 namespace PacBio {
 namespace CLI {
 namespace ToolContract {
 
+static_assert(std::is_copy_constructible<Driver>::value, "Driver(const Driver&) is not = default");
+static_assert(std::is_copy_assignable<Driver>::value,
+              "Driver& operator=(const Driver&) is not = default");
+
+static_assert(std::is_nothrow_move_constructible<Driver>::value,
+              "Driver(Driver&&) is not = noexcept");
+static_assert(std::is_nothrow_move_assignable<Driver>::value ==
+                  std::is_nothrow_move_assignable<std::string>::value,
+              "");
+
 inline Driver::Driver(std::string exe) : exe_{std::move(exe)} {}
 
 inline Driver::Driver(std::string exe, Environment env, std::string serialization)
@@ -16,7 +29,7 @@ inline Driver::Driver(std::string exe, Environment env, std::string serializatio
 {
 }
 
-inline const Driver::Environment& Driver::Env(void) const { return env_; }
+inline const Driver::Environment& Driver::Env() const { return env_; }
 
 inline Driver& Driver::Env(Driver::Environment env)
 {
@@ -24,7 +37,7 @@ inline Driver& Driver::Env(Driver::Environment env)
     return *this;
 }
 
-inline const std::string& Driver::Exe(void) const { return exe_; }
+inline const std::string& Driver::Exe() const { return exe_; }
 
 inline Driver& Driver::Exe(std::string exe)
 {
@@ -32,7 +45,7 @@ inline Driver& Driver::Exe(std::string exe)
     return *this;
 }
 
-inline const std::string& Driver::Serialization(void) const { return serialization_; }
+inline const std::string& Driver::Serialization() const { return serialization_; }
 
 inline Driver& Driver::Serialization(std::string serialization)
 {
