@@ -3,10 +3,11 @@
 #ifndef PBCOPPER_DATA_POSITION_H
 #define PBCOPPER_DATA_POSITION_H
 
-#include <cstdint>
-
 #include <pbcopper/PbcopperConfig.h>
 
+#include <cstdint>
+#include <limits>
+
 namespace PacBio {
 namespace Data {
 
@@ -14,6 +15,8 @@ typedef int32_t Position;
 
 static const Position UnmappedPosition = Position{-1};
 
+constexpr Position MaximumPosition = std::numeric_limits<decltype(MaximumPosition)>::max();
+
 }  // namespace Data
 }  // namespace PacBio
 
