@@ -3,10 +3,11 @@
 #ifndef PBCOPPER_QGRAM_INDEXHIT_H
 #define PBCOPPER_QGRAM_INDEXHIT_H
 
-#include <cstdint>
-
 #include <pbcopper/PbcopperConfig.h>
 
+#include <cstdint>
+#include <tuple>
+
 namespace PacBio {
 namespace QGram {
 
@@ -23,7 +24,7 @@ public:
     ///
     /// \brief IndexHit
     ///
-    IndexHit(void) : id_(0), position_(0) {}
+    IndexHit() = default;
 
     ///
     /// \brief IndexHit
@@ -32,27 +33,22 @@ public:
     ///
     IndexHit(const uint32_t id, const uint64_t pos) : id_(id), position_(pos) {}
 
-    IndexHit(const IndexHit&) = default;
-    IndexHit(IndexHit&&) = default;
-    IndexHit& operator=(const IndexHit&) = default;
-    IndexHit& operator=(IndexHit&&) = default;
-
 public:
     ///
     /// \brief Id
     /// \return id (index number) of Index input sequence containing this hit
     ///
-    uint32_t Id(void) const { return id_; }
+    uint32_t Id() const { return id_; }
 
     ///
     /// \brief Position
     /// \return position of hit
     ///
-    uint64_t Position(void) const { return position_; }
+    uint64_t Position() const { return position_; }
 
 private:
-    uint32_t id_;
-    uint64_t position_;
+    uint32_t id_ = 0;
+    uint64_t position_ = 0;
 };
 
 ///
@@ -63,7 +59,7 @@ private:
 ///
 inline bool operator==(const IndexHit& lhs, const IndexHit& rhs)
 {
-    return lhs.Id() == rhs.Id() && lhs.Position() == rhs.Position();
+    return std::make_tuple(lhs.Id(), lhs.Position()) == std::make_tuple(rhs.Id(), rhs.Position());
 }
 
 }  // namespace QGram
